summaryrefslogtreecommitdiff
path: root/include/internal/routines/level2/xgbmv.h
diff options
context:
space:
mode:
authorCNugteren <web@cedricnugteren.nl>2015-09-18 17:46:41 +0200
committerCNugteren <web@cedricnugteren.nl>2015-09-18 17:46:41 +0200
commit93dddda63e4345961a779ee125d748c1eeef4769 (patch)
treeecb99fedbe765152259dec595833431b703e2fb3 /include/internal/routines/level2/xgbmv.h
parent4507ba4997cd546418eae0972c018073ac7b36aa (diff)
Improved the organization and performance of level 2 routines
Diffstat (limited to 'include/internal/routines/level2/xgbmv.h')
-rw-r--r--include/internal/routines/level2/xgbmv.h17
1 files changed, 4 insertions, 13 deletions
diff --git a/include/internal/routines/level2/xgbmv.h b/include/internal/routines/level2/xgbmv.h
index 763168d4..27b033e9 100644
--- a/include/internal/routines/level2/xgbmv.h
+++ b/include/internal/routines/level2/xgbmv.h
@@ -7,10 +7,9 @@
// Author(s):
// Cedric Nugteren <www.cedricnugteren.nl>
//
// This file implements the Xgbmv routine. It is based on the generalized matrix multiplication
// routine (Xgemv). The Xgbmv class inherits from the templated class Xgemv, allowing it to call the
-// "DoGemm" function directly. The "DoGbmv" function first preprocesses the banded matrix by
-// transforming it into a general matrix, and then calls the regular GEMV code.
+// "MatVec" function directly.
//
// =================================================================================================
@@ -27,16 +26,8 @@ template <typename T>
class Xgbmv: public Xgemv<T> {
public:
- // Members and methods from the base class
- using Routine<T>::db_;
- using Routine<T>::context_;
- using Routine<T>::GetProgramFromCache;
- using Routine<T>::TestMatrixA;
- using Routine<T>::RunKernel;
- using Routine<T>::ErrorIn;
-
- // Uses the regular Xgemv routine
- using Xgemv<T>::DoGemv;
+ // Uses the generic matrix-vector routine
+ using Xgemv<T>::MatVec;
// Constructor
Xgbmv(Queue &queue, Event &event, const std::string &name = "GBMV");
@@ -7,10 +7,9 @@
// Cedric Nugteren <www.cedricnugteren.nl>
//
-// This file implements the Xgbmv routine. It is based on the generalized matrix multiplication
+// This file implements the Xgbmv routine. It is based on the generalized mat-vec multiplication
// routine (Xgemv). The Xgbmv class inherits from the templated class Xgemv, allowing it to call the